/// <reference types="node" />
import FormData from 'form-data';
import { URL } from 'url';
import { AddDirectoryResponse, AddParams, AddResponse, FileWithName, PinOptions, PinResponse, RequestOptions, StatusOptions, StatusResponse } from './types';
export declare class IpfsClusterClient {
    /**
     * @param {URL|string} url Cluster HTTP API root URL.
     * @param {{ headers?: Record<string, string> }} [options]
     */
    readonly clusterHost: URL;
    /**
     * base64 encoded
     */
    private readonly authorizationHeader;
    constructor(host: string, username?: string, password?: string);
    /**
     * @param {API.RequestOptions} [options]
     */
    version(options?: RequestOptions): Promise<any>;
    /**
     * @param {API.RequestOptions} [options]
     * @returns {Promise<API.ClusterInfo>}
     */
    info(options?: RequestOptions): Promise<{
        id: any;
        addresses: any;
        version: any;
        commit: any;
        peerName: any;
        rpcProtocolVersion: any;
        clusterPeers: any;
        clusterPeersAddresses: any;
        ipfs: any;
    }>;
    constructHeaders(headers?: Record<string, string>): Record<string, string>;
    addFromFormData(formData: FormData, options?: AddParams): Promise<AddResponse>;
    /**
     * For endpoint https://docs.ipfs.io/reference/http/api/#api-v0-add
     */
    addFile(file: FileWithName, options?: AddParams): Promise<AddResponse>;
    addData(file: FileWithName, options: AddParams): Promise<AddResponse>;
    addDirectory(files: FileWithName[], options?: RequestOptions): Promise<AddDirectoryResponse>;
    pin(cid: string, options: PinOptions): Promise<PinResponse>;
    unpin(cid: string, options?: RequestOptions): Promise<PinResponse>;
    pinls(options: RequestOptions): Promise<PinResponse>;
    status(cid: string, options?: StatusOptions): Promise<StatusResponse>;
    allocation(cid: string, options?: RequestOptions): Promise<PinResponse>;
    recover(cid: string, options?: RequestOptions): Promise<StatusResponse>;
    /**
     * @param {API.RequestOptions} [options]
     * @returns {Promise<string[]>}
     */
    metricNames(options?: RequestOptions): Promise<any>;
}
