"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.request = void 0;
const url_1 = require("url");
const axios_1 = __importDefault(require("axios"));
const utils_1 = require("./utils");
/**
 * streaming data with axios
 * https://maximorlov.com/send-a-file-with-axios-in-nodejs/
 *
 * Multipart boundary data
 * https://stackoverflow.com/questions/3508338/what-is-the-boundary-in-multipart-form-data
 */
/**
 *
 * @param {API.Config} clusterClient
 * @param {string} path
 * @param {Object} [options]
 * @param {string} [options.method]
 * @param {Record<string, string|number|boolean|null|undefined>} [options.params]
 * @param {BodyInit} [options.body]
 * @param {AbortSignal} [options.signal]
 */
async function request(baseUrl, path, headers, options) {
    const endpoint = new url_1.URL(path, baseUrl);
    for (const [key, value] of Object.entries((options === null || options === void 0 ? void 0 : options.params) || {})) {
        if (value != null) {
            endpoint.searchParams.set(key, String(value));
        }
    }
    const config = {
        method: options === null || options === void 0 ? void 0 : options.method,
        url: endpoint.href,
        data: options === null || options === void 0 ? void 0 : options.body,
        headers,
        signal: options === null || options === void 0 ? void 0 : options.signal,
    };
    try {
        const response = await (0, axios_1.default)(config);
        return response.data;
    }
    catch (err) {
        utils_1.Utils.logAxiosError(err);
        throw err;
    }
}
exports.request = request;
