"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TrackerStatus = exports.PinType = void 0;
var PinType;
(function (PinType) {
    /**
     * Bad type showing up anywhere indicates a bug
     */
    PinType[PinType["BAD"] = 1] = "BAD";
    /**
     * Data is a regular, non-sharded pin. It is pinned recursively.
     * It has no associated reference.
     */
    PinType[PinType["DATA"] = 2] = "DATA";
    /**
     * Meta tracks the original CID of a sharded DAG. Its Reference points to the
     * Cluster DAG CID.
     */
    PinType[PinType["META"] = 3] = "META";
    /**
     * ClusterDAG pins carry the CID of the root node that points to all the
     * shard-root-nodes of the shards in which a DAG has been divided. Its
     * Reference carries the MetaType CID.
     * ClusterDAGType pins are pinned directly everywhere.
     */
    PinType[PinType["CLUSTER_DAG"] = 4] = "CLUSTER_DAG";
    /**
     * Shard pins carry the root CID of a shard, which points to individual blocks
     * on the original DAG that the user is adding, which has been sharded. They
     * carry a Reference to the previous shard. ShardTypes are pinned with
     * MaxDepth=1 (root and direct children only).
     */
    PinType[PinType["SHARD"] = 5] = "SHARD";
})(PinType = exports.PinType || (exports.PinType = {}));
var TrackerStatus;
(function (TrackerStatus) {
    /**
     * IPFSStatus should never take this value. When used as a filter. It means
     * "all".
     */
    TrackerStatus["UNDEFINED"] = "undefined";
    /**
     * The cluster node is offline or not responding.
     */
    TrackerStatus["CLUSTER_ERROR"] = "cluster_error";
    /**
     * An error occurred pinning.
     */
    TrackerStatus["PIN_ERROR"] = "pin_error";
    /**
     * An error occurred unpinning.
     */
    TrackerStatus["UNPIN_ERROR"] = "unpin_error";
    /**
     * The IPFS daemon has pinned the item.
     */
    TrackerStatus["PINNED"] = "pinned";
    /**
     * The IPFS daemon is currently pinning the item.
     */
    TrackerStatus["PINNING"] = "pinning";
    /**
     * The IPFS daemon is currently unpinning the item.
     */
    TrackerStatus["UNPINNING"] = "unpinning";
    /**
     * The IPFS daemon is not pinning the item.
     */
    TrackerStatus["UNPINNED"] = "unpinned";
    /**
     * The IPFS daemon is not pinning the item but it is being tracked.
     */
    TrackerStatus["REMOTE"] = "remote";
    /**
     * The item has been queued for pinning on the IPFS daemon.
     */
    TrackerStatus["PIN_QUEUED"] = "pin_queued";
    /**
     * The item has been queued for unpinning on the IPFS daemon.
     */
    TrackerStatus["UNPIN_QUEUED"] = "unpin_queued";
    /**
     * The IPFS daemon is not pinning the item through this CID but it is tracked
     * in a cluster dag
     */
    TrackerStatus["SHARDED"] = "sharded";
})(TrackerStatus = exports.TrackerStatus || (exports.TrackerStatus = {}));
