/// <reference types="node" />
import { URLSearchParams } from 'url';
import { IpfsClusterClient } from './ipfs-cluster.client';
import { AddParams, PinOptions, PinResponse, RequestOptions } from './types';
export declare class Utils {
    /**
     * Gets cluster version
     *
     * @param {API.Config} cluster
     * @param {API.RequestOptions} [options]
     * @returns {Promise<string>}
     */
    static version(cluster: IpfsClusterClient, headers: Record<string, string>, options?: RequestOptions): Promise<any>;
    /**
     * Gets cluster information
     *
     * @param {API.Config} cluster
     * @param {API.RequestOptions} [options]
     * @returns {Promise<API.ClusterInfo>}
     */
    static info(cluster: IpfsClusterClient, headers: Record<string, string>, options?: RequestOptions): Promise<{
        id: any;
        addresses: any;
        version: any;
        commit: any;
        peerName: any;
        rpcProtocolVersion: any;
        clusterPeers: any;
        clusterPeersAddresses: any;
        ipfs: any;
    }>;
    static encodeAddParams(options?: AddParams): URLSearchParams;
    static getPinParams(options: PinOptions): {
        name: string | undefined;
        mode: "recursive" | "direct" | undefined;
        'replication-min': string | undefined;
        'replication-max': string | undefined;
        'shard-size': string | undefined;
        'user-allocations': string | undefined;
        'expire-at': string | undefined;
        'pin-update': string | undefined;
        origins: string | undefined;
    };
    static filterUndefinedProperties(obj: Record<string, string | undefined>): Record<string, string>;
    static encodeMetadata(metadata: Record<string, string>): {
        [k: string]: string;
    };
    static toPinResponse(data: any): PinResponse;
    static logAxiosError(err: any): void;
}
